* ***************************************
* IMMIGRATION AND SUPPORT FOR WELFARE 
*    IN GERMANY 
* Analyzing ALLBUS data 1994, 2000, 2004
*   2010 merged with census data
*   using mixed effects ordered probit 
*   models with decomposition of within
*   and between effects
* Author: Alexander Schmidt
* Date: 04/13/2015	
*****************************************

clear
set more off
************************************
capture log close
log using Analyze_Data.log, replace
use data_complete.dta


			
* generate interaction terms
gen ia_foreign_unemplr = foreign*unemplr		// interaction at context-level
gen foreign_sq = foreign^2
gen ia_foreign_sq_unemplr = foreign_sq*unemplr
		
foreach var of varlist foreign foreign_sq unemplr gdppc ia_foreign_unemplr ia_foreign_sq_unemplr {
bys ror08: egen `var'_m = mean(`var')
gen `var'_dm = `var' - `var'_m
}

* Generate West dummy
recode v5 2=0, gen(west)


* Generate year dummies
tab year, gen(year_)
	rename year_2 y2000
	rename year_3 y2004
	rename year_4 y2010

	

* Analysis 

* individual level variables only (Ref for education is lower secondary = middle category)
meglm morewel || ror08: || year: , link(probit) fam(ordinal) diff
est store m0

meglm morewel y2000 y2004 y2010 male age married primary higher_secondary employed unemployed leftright ///
income_hh_equiv comsize_2 comsize_3 comsize_4 comsize_5 comsize_6 comsize_7 west || ror08: || year: , link(probit) fam(ordinal) diff
est store m1

* add context variables as between and within components
meglm morewel y2000 y2004 y2010 male age married primary higher_secondary employed unemployed leftright income_hh_equiv comsize_2 comsize_3 comsize_4 comsize_5 comsize_6 comsize_7 west ///
foreign_m foreign_dm unemplr_m unemplr_dm gdppc_m gdppc_dm || ror08: || year: , link(probit) fam(ordinal) diff
est store m2

* Different effects depending on the level
meglm morewel y2000 y2004 y2010 male age married primary higher_secondary employed unemployed leftright income_hh_equiv comsize_2 comsize_3 comsize_4 comsize_5 comsize_6 comsize_7 west ///
foreign_m foreign_sq_m foreign_dm foreign_sq_dm unemplr_m unemplr_dm gdppc_m gdppc_dm || ror08: || year: , link(probit) fam(ordinal) diff
est store m3

* make a figure from model 3 (marginal effect plot)
* This marginal effect is calculated for the observed range of the original share of foreigners variable,
*    as should be done in FE panel models
capture drop xaxis yaxis*
gen xaxis = .
gen yaxis_pe = .
gen yaxis_lb = .
gen yaxis_ub = .
local i = 0
foreach num of numlist 1(.5)17.5 {
local i = `i'+1 
replace xaxis = `num' in `i'
lincom foreign_dm+2*(`num')*foreign_sq_dm
replace yaxis_pe =  r(estimate) in `i'
replace yaxis_lb= r(estimate)-1.96*r(se) in `i'
replace yaxis_ub= r(estimate)+1.96*r(se) in `i'
}

* Figure 1 (from main article)
twoway line yaxis_* xaxis, scheme(s1mono) yline(0, lc(black)) legend(off) ytitle("Marginal effect of share of foreigners (in %)") xtitle("Share of foreigners (in %)") ///
lp(solid dash dash) lc(black black black) name(margeff, replace) saving(Figure1.gph, replace)



* Include interaction at context-level
meglm morewel y2000 y2004 y2010 male age married primary higher_secondary employed unemployed leftright income_hh_equiv comsize_2 comsize_3 comsize_4 comsize_5 comsize_6 comsize_7 west ///
foreign_m foreign_dm ia_foreign_unemplr_m ia_foreign_unemplr_dm unemplr_m unemplr_dm gdppc_m gdppc_dm || ror08: || year: , link(probit) fam(ordinal) diff
est store m4		



* make a figure from that
* This marginal effect is calculated for the observed range of the original share of foreigners variable,
*    as should be done in FE panel models
capture drop xaxis yaxis*
gen xaxis = .
gen yaxis_pe = .
gen yaxis_lb = .
gen yaxis_ub = .
local i = 0
foreach num of numlist 3.3(.5)26.3 {
local i = `i'+1 
replace xaxis = `num' in `i'
lincom foreign_dm+(`num')*ia_foreign_unemplr_dm
replace yaxis_pe =  r(estimate) in `i'
replace yaxis_lb= r(estimate)-1.96*r(se) in `i'
replace yaxis_ub= r(estimate)+1.96*r(se) in `i'
}
twoway line yaxis_* xaxis, scheme(s1mono) yline(0, lc(black)) legend(off) ytitle("Marginal effect of share of foreigners (in %)") xtitle("Unemployment rate (in %)") ///
lp(solid dash dash) lc(black black black) saving(Figure2.gph, replace)


* Include a three way interaction
meglm morewel y2000 y2004 y2010 male age married primary higher_secondary employed unemployed leftright income_hh_equiv comsize_2 comsize_3 comsize_4 comsize_5 comsize_6 comsize_7 west ///
foreign_m foreign_dm foreign_sq_m foreign_sq_dm ia_foreign_unemplr_m ia_foreign_unemplr_dm ia_foreign_sq_unemplr_m ia_foreign_sq_unemplr_dm unemplr_m unemplr_dm gdppc_m gdppc_dm || ror08: || year: , link(probit) fam(ordinal) diff
est store m5		


* make a figure from that
* This marginal effect is calculated for the observed range of unemployment rates, 
*    as should be done in FE panel models
* as the foreigner effect is nonlinear, I set it to three different values (min/mean/max)

capture drop xaxis yaxis*
gen xaxis = .
gen yaxisFmin_pe = .
gen yaxisFmean_pe = .
gen yaxisFmax_pe = .
gen yaxisFmin_lb = .
gen yaxisFmean_lb = .
gen yaxisFmax_lb = .
gen yaxisFmin_ub = .
gen yaxisFmean_ub = .
gen yaxisFmax_ub = .
local i = 0
foreach num of numlist 3.3(.5)26.3 {
local i = `i'+1 
replace xaxis = `num' in `i'
lincom foreign_dm+2*foreign_sq_dm*(2.46)+ia_foreign_unemplr_dm*(`num')+2*ia_foreign_sq_unemplr_dm*(2.46)*(`num')
replace yaxisFmin_pe =  r(estimate) in `i'
replace yaxisFmin_lb= r(estimate)-1.96*r(se) in `i'
replace yaxisFmin_ub= r(estimate)+1.96*r(se) in `i'
lincom foreign_dm+2*foreign_sq_dm*(7.21)+ia_foreign_unemplr_dm*(`num')+2*ia_foreign_sq_unemplr_dm*(7.21)*(`num')
replace yaxisFmean_pe =  r(estimate) in `i'
replace yaxisFmean_lb= r(estimate)-1.96*r(se) in `i'
replace yaxisFmean_ub= r(estimate)+1.96*r(se) in `i'
lincom foreign_dm+2*foreign_sq_dm*(11.96)+ia_foreign_unemplr_dm*(`num')+2*ia_foreign_sq_unemplr_dm*(11.96)*(`num')
replace yaxisFmax_pe =  r(estimate) in `i'
replace yaxisFmax_lb= r(estimate)-1.96*r(se) in `i'
replace yaxisFmax_ub= r(estimate)+1.96*r(se) in `i'
}

twoway line yaxis*  xaxis, scheme(s1mono) yline(0, lc(black)) legend(off) ytitle("Marginal effect of share of foreigners (in %)") ///
 xtitle("Unemployment rate (in %)") lp(dash solid longdash dash solid longdash dash solid longdash) ///
 lc(gs0 gs0 gs0 gs10 gs10 gs10 gs10 gs10 gs10) lw(thick thick thick thin thin thin thin thin thin)
 
twoway line yaxis?min*  xaxis, scheme(s1mono) yline(0, lc(black)) legend(off) ytitle("Marginal effect of share of foreigners (in %)") ///
 xtitle("Unemployment rate (in %)") lp(solid dash dash) lc(black black black) saving(Figure3a.gph, replace) ///
 title("Share of foreigners = min (2.46%)")
twoway line yaxis?mean*  xaxis, scheme(s1mono) yline(0, lc(black)) legend(off) ytitle("Marginal effect of share of foreigners (in %)") ///
 xtitle("Unemployment rate (in %)") lp(solid dash dash) lc(black black black) saving(Figure3b.gph, replace) ///
 title("Share of foreigners = mean (7.21%)")
twoway line yaxis?max*  xaxis, scheme(s1mono) yline(0, lc(black)) legend(off) ytitle("Marginal effect of share of foreigners (in %)") ///
 xtitle("Unemployment rate (in %)") lp(solid dash dash) lc(black black black) saving(Figure3c.gph, replace) ///
 title("Share of foreigners = max (11.96%)")
 
 	
est tab m0 m1 m2 m3 m4 m5, star(.05 .01 .001) stats(N aic bic ll)
est tab m0 m1 m2 m3 m4 m5,  stats(N aic bic ll) 
est tab m0 m1 m2 m3 m4 m5, b(%9.4f) se(%9.4f)

* compare models

lrtest m1 m2
lrtest m2 m3
lrtest m2 m4
lrtest m4 m5

	
* descriptive analyses

xtile foreign_c_w = foreign if west == 1, n(3) 
pctile foreign_c_w_cats = foreign if west == 1, n(3)
xtile foreign_c_o = foreign if west == 0, n(3) 
pctile foreign_c_o_cats = foreign if west == 0, n(3)
xtile foreign_c = foreign, n(3)
pctile foreign_c_cats = foreign, n(3)

* Table 1a-1c (main paper)
tab morewel foreign_c, col chi2 V
tab morewel foreign_c_w, col chi2 V
tab morewel foreign_c_o, col chi2 V


* Table X (main paper)
tab morewel year, nofre col


* (Online) Appendix

tab ror08 year
tab ror08name year
corr morewel male age married primary lower_secondary higher_secondary employed unemployed nilf ///
 leftright income_hh_equiv comsize foreign foreign_m foreign_dm unemplr unemplr_m unemplr_dm gdppc gdppc_m gdppc_dm west 


sum morewel male age married primary lower_secondary higher_secondary employed unemployed nilf ///
 leftright income_hh_equiv comsize foreign foreign_m foreign_dm unemplr unemplr_m unemplr_dm gdppc gdppc_m gdppc_dm west
 
************************************* 
 log close
